@@ -1,12 +1,11 @@
 // +build !linux !arm64
 // +build !windows
+// +build go1.7
 
 package daemon
 
-import (
-	"syscall"
-)
+import "golang.org/x/sys/unix"
 
 func syscallDup(oldfd int, newfd int) (err error) {
-	return syscall.Dup2(oldfd, newfd)
+	return unix.Dup2(oldfd, newfd)
 }
